@@ -77,12 +77,12 @@ try:
 except ImportError:
     from StringIO import StringIO
 
-invalid_key_characters = ''.join(map(chr, range(33) + [127]))
+valid_key_chars_re = re.compile('[\x21-\x7e\x80-\xff]+$')
 
 
 #  Original author: Evan Martin of Danga Interactive
 __author__    = "Sean Reifschneider <jafo-memcached@tummy.com>"
-__version__ = "1.51"
+__version__ = "1.52"
 __copyright__ = "Copyright (C) 2003 Danga Interactive"
 #  http://en.wikipedia.org/wiki/Python_Software_Foundation_License
 __license__   = "Python Software Foundation License"
@@ -697,7 +697,8 @@ class Client(local):
 
         self._statlog('set_multi')
 
-        server_keys, prefixed_to_orig_key = self._map_and_prefix_keys(mapping.iterkeys(), key_prefix)
+        server_keys, prefixed_to_orig_key = self._map_and_prefix_keys(
+                mapping.iterkeys(), key_prefix)
 
         # send out all requests on each server before reading anything
         dead_servers = []
@@ -1046,11 +1047,10 @@ class Client(local):
                 len(key) + key_extra_len > self.server_max_key_length:
                 raise Client.MemcachedKeyLengthError("Key length is > %s"
                          % self.server_max_key_length)
-            if len(key) != len(key.translate(None, invalid_key_characters)):
+            if not valid_key_chars_re.match(key):
                 raise Client.MemcachedKeyCharacterError(
                         "Control characters not allowed")
 
-
 class _Host(object):
 
     def __init__(self, host, debug=0, dead_retry=_DEAD_RETRY,
